 /*
  * Copyright (C), 2018-2022
  * Project: starter
  * FileName: PagePainterPlus
  * Author:   xx
  * Date:     2022/9/27 14:17
  */
 package com.fr.plugin.ajhdf.painter;

 import com.fr.base.DynamicNumberList;
 import com.fr.base.Style;
 import com.fr.interruption.Condition;
 import com.fr.interruption.Conditions;
 import com.fr.interruption.ExporterScene;
 import com.fr.page.ClippedPageProvider;
 import com.fr.page.PagePainter;
 import com.fr.page.ReportPageProvider;
 import com.fr.plugin.ajhdf.style.StylePDF;
 import com.fr.report.cell.CellElement;
 import com.fr.report.cell.cellattr.BrokenCellInfo;
 import com.fr.report.cell.cellattr.CellGUIAttr;
 import com.fr.report.cell.cellattr.PageExportCellElement;
 import com.fr.stable.monitor.MemoryHelper;
 import org.jetbrains.annotations.NotNull;

 import java.awt.*;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;

 /**
  * <Function Description><br>
  * <PagePainterPlus>
  *
  * @author xx
  * @since 1.0.0
  */
 public class PagePainterPlus extends PagePainter {
     private boolean isPrint;

     private float scale;

     public PagePainterPlus() {
         super();
     }

     public PagePainterPlus(ReportPageProvider reportPage, Graphics2D g2d, int resolution, boolean isPrint) {
         super(reportPage, g2d, resolution, isPrint);
     }

     public PagePainterPlus(ReportPageProvider reportPage, Graphics2D g2d, int resolution, boolean isPrint, float scale) {
         super(reportPage, g2d, resolution, isPrint);
         this.scale = scale;
     }

     public PagePainterPlus(ReportPageProvider reportPage, Graphics2D g2d, int resolution, boolean isPrint, boolean isShowAsImageInWeb) {
         super(reportPage, g2d, resolution, isPrint, isShowAsImageInWeb);
     }

     @Override
     public void prepareCell(ClippedPageProvider page, DynamicNumberList columnWidthList, DynamicNumberList rowHeightList, int offsetX, int offsetY) {
         List<CellElement> cellElements = new ArrayList<>();
         List<Rectangle> rectangles = new ArrayList<>();
         List<Rectangle> rectangleList = new ArrayList<>();
         Iterator cellIterator = page.cellIterator();
         Condition condition = Conditions.get(ExporterScene.PDF_CELL);
         int cellIndex = 0;

         Rectangle cellRectangle;
         while (cellIterator.hasNext()) {
             PageExportCellElement pageExportCellElement = new PageExportCellElement((CellElement) cellIterator.next());
             CellGUIAttr cellGUIAttr = pageExportCellElement.getCellGUIAttr();
             if (cellGUIAttr == null) {
                 cellGUIAttr = CellGUIAttr.DEFAULT_CELLGUIATTR;
             }

             cellRectangle = new Rectangle(pageExportCellElement.getColumn(), pageExportCellElement.getRow(), pageExportCellElement.getColumnSpan(), pageExportCellElement.getRowSpan());
             Rectangle rangeRectangle = new Rectangle(columnWidthList.getRangeValue(0, cellRectangle.x), rowHeightList.getRangeValue(0, cellRectangle.y), columnWidthList.getRangeValue(cellRectangle.x, cellRectangle.x + cellRectangle.width), rowHeightList.getRangeValue(cellRectangle.y, cellRectangle.y + cellRectangle.height));
             rangeRectangle.x += offsetX;
             rangeRectangle.y += offsetY;
             this.paintCellAfterPrepare(pageExportCellElement, cellGUIAttr, rangeRectangle, cellElements, rectangles, rectangleList);
             ++cellIndex;
             if ((cellIndex & 7) == 0) {
                 condition.setMetric(cellIndex);
                 MemoryHelper.getMemoryAlarmProcessor().interruptIfConditionMet(condition);
             }
         }

         int count = 0;
         for (int i = cellElements.size(); count < i; ++count) {
             CellElement element = (CellElement) cellElements.get(count);
             cellRectangle = (Rectangle) rectangles.get(count);
             Rectangle rectangle = (Rectangle) rectangleList.get(count);
             // 修改边框样式
             StylePDF.paintBorder(this.g2d, element.getStyle(), cellRectangle, rectangle, this.scale);
             if ((count & 7) == 0) {
                 condition.setMetric(cellIndex);
                 MemoryHelper.getMemoryAlarmProcessor().interruptIfConditionMet(condition);
             }
         }
     }

     private void paintCellAfterPrepare(PageExportCellElement pageExportCellElement, CellGUIAttr cellGUIAttr, Rectangle rectangle, java.util.List<CellElement> cellElements, java.util.List<Rectangle> rectangles, List<Rectangle> rectangles1) {
         BrokenCellInfo brokenCellInfo = pageExportCellElement.getBrokenCellInfo();
         Rectangle tmpRectangle;
         if (brokenCellInfo != null && brokenCellInfo.getClipInfo() != null) {
             tmpRectangle = brokenCellInfo.getClipInfo();
         } else {
             tmpRectangle = new Rectangle(0, 0, rectangle.width, rectangle.height);
         }

         if (brokenCellInfo != null && brokenCellInfo.getPaintInfo() != null) {
             Rectangle paintInfo = brokenCellInfo.getPaintInfo();
             rectangle.x += paintInfo.x;
             rectangle.y += paintInfo.y;
             rectangle.width = paintInfo.width;
             rectangle.height = paintInfo.height;
         }

         cellElements.add(pageExportCellElement);
         rectangles.add(rectangle);
         rectangles1.add(tmpRectangle);
         if (this.needPaintCell(rectangle)) {
             if (this.shouldPaintCellBackground(cellGUIAttr)) {
                 Style.paintBackground(this.g2d, pageExportCellElement.getStyle(), rectangle, tmpRectangle);
             }

             this.paintCellContent(cellGUIAttr, this.isPrint, pageExportCellElement, rectangle, tmpRectangle);
         }
     }

     private boolean needPaintCell(@NotNull Rectangle rectangle) {
         return 0 < rectangle.width && 0 < rectangle.height;
     }

     private boolean shouldPaintCellBackground(CellGUIAttr cellGUIAttr) {
         return this.isPrint && cellGUIAttr.isPrintBackground() || !this.isPrint && cellGUIAttr.isPrintBackground();
     }
 }