package com.fr.plugin.ajhdf.provider;

import com.fanruan.api.i18n.I18nKit;
import com.fanruan.api.log.LogKit;
import com.fr.io.collection.ExportCollection;
import com.fr.plugin.ajhdf.operate.CustomPDFOperate;
import com.fr.plugin.context.PluginContexts;
import com.fr.stable.fun.Authorize;
import com.fr.web.core.ReportSessionIDInfor;
import com.fr.web.core.reserve.DefaultExportExtension;
import com.fr.web.core.reserve.DefaultOperate;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.Map;

import static com.fr.plugin.ajhdf.LocaleFinder.PLUGIN_ID;

/**
 * 默认的实现是在DefaultExportExtension里面的，因为修改的只是pdf导出的部分逻辑
 * 所以直接继承DefaultExportExtension
 */
@Authorize(callSignKey = PLUGIN_ID)
public class FileExportExtension extends DefaultExportExtension {
    private static Map<String, DefaultOperate> operateMap = new HashMap<String, DefaultOperate>();

    static {
        operateMap.put("pdf", new CustomPDFOperate());
    }

    @Override
    public ExportCollection createCollection(HttpServletRequest req, HttpServletResponse res, ReportSessionIDInfor reportSessionIDInfor, String format, String fileName, boolean isEmbed) throws Exception {
        if (PluginContexts.currentContext() == null || !PluginContexts.currentContext().isAvailable()) {
            LogKit.error(I18nKit.getLocText("Plugin-ajhdf_licence_Expired"));
            return super.createCollection(req, res, reportSessionIDInfor, format, fileName, isEmbed);
        }
        DefaultOperate operate = operateMap.get(format.toLowerCase());
        if (operate != null) {
            return operate.newExportCollection(req, res, reportSessionIDInfor, fileName);
        }
        return super.createCollection(req, res, reportSessionIDInfor, format, fileName, isEmbed);
    }
}
